From: Jeff King Date: Sat, 17 Dec 2011 11:19:20 GMT Subject: Re: [PATCH 1/3] use struct sha1_array in diff_tree_combined() Message-ID: <20111217111920.GA24917@sigill.intra.peff.net> In-Reply-To: <4EEC7A10.3080705@lsrfire.ath.cx> On Sat, Dec 17, 2011 at 12:16:32PM +0100, René Scharfe wrote: > >The original code is slightly more efficient, as it is able to use a > >single malloc (because it knows the number of entries ahead of time). > >It probably doesn't make a difference, but we could also add a > >sha1_array_grow() for this case. > [...] > We coulddo that, yes. In the case above we have the number already, > in the other cases we'd have to count. > > But I don't think it's worth it here. ALLOC_GROW gives us 24 entries > initially, which should be enough in most cases -- I'm not sure I > want to see combined diff of that many tree. And 24 times 20 bytes > is small enough to not cause any memory allocation issues. You're right. I was blindly looking at the conversion without thinking about the context. Of course if you have just a few items, it's going to be irrelevant (my initial refactoring of sha1_array was to help speed up a hundreds-of-thousands of sha1s case, so I think that put me in the mindset of a large list). Sorry for the noise. -Peff